summaryrefslogtreecommitdiff
path: root/src/mongo/client
diff options
context:
space:
mode:
authorKelsey Schubert <kelsey@mongodb.com>2018-11-06 13:52:16 -0500
committerKelsey Schubert <kelsey@mongodb.com>2018-11-12 11:54:35 -0500
commit69d9ed13583bff9947d3838dd5308d1c35fa3445 (patch)
tree1ed7332de874b9c6558fec6635c721ab48be2487 /src/mongo/client
parent4cafb0b8f0566d7e480983fc57b94b7bfe78c540 (diff)
downloadmongo-69d9ed13583bff9947d3838dd5308d1c35fa3445.tar.gz
SERVER-37809 Fix typo in mongo shell error message
Diffstat (limited to 'src/mongo/client')
-rw-r--r--src/mongo/client/mongo_uri.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/client/mongo_uri.cpp b/src/mongo/client/mongo_uri.cpp
index 72892f2d1a2..597933712df 100644
--- a/src/mongo/client/mongo_uri.cpp
+++ b/src/mongo/client/mongo_uri.cpp
@@ -114,7 +114,7 @@ namespace {
/**
* Helper Method for MongoURI::parse() to split a string into exactly 2 pieces by a char
- * delimeter.
+ * delimiter.
*/
std::pair<StringData, StringData> partitionForward(StringData str, const char c) {
const auto delim = str.find(c);
@@ -276,12 +276,12 @@ URIParts::URIParts(StringData uri) {
const auto userAndHostInfo = userAndDb.first;
// 2.b Make sure that there are no question marks in the left side of the /
// as any options after the ? must still have the / delimeter
if (userAndDb.second.empty() && userAndHostInfo.find('?') != std::string::npos) {
uasserted(
ErrorCodes::FailedToParse,
str::stream()
- << "URI must contain slash delimeter between hosts and options for mongodb:// URL: "
+ << "URI must contain slash delimiter between hosts and options for mongodb:// URL: "
<< uri);
}
@@ -276,12 +276,12 @@ URIParts::URIParts(StringData uri) {
const auto userAndHostInfo = userAndDb.first;
// 2.b Make sure that there are no question marks in the left side of the /
- // as any options after the ? must still have the / delimeter
+ // as any options after the ? must still have the / delimiter
if (userAndDb.second.empty() && userAndHostInfo.find('?') != std::string::npos) {
uasserted(